@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.018-7-g36c7381
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.019-3-g1be444e
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
@@ -119,6 +119,14 @@ sub register_prereqs
 
     # see https://github.com/makamaka/JSON-PP/pull/9 for for details
     $self->log('Warning: distribution has non-ascii characters in contributor names. META.json will be unparsable on perls <= 5.8.6 when JSON::PP is lower than 2.27300');
+
+    $self->zilla->register_prereqs(
+        {
+            phase => 'configure',
+            type  => 'suggests',
+        },
+        'JSON::PP' => '2.27300',
+    );
 }
 
 # should not be called before the MetaProvider phase
@@ -251,7 +259,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 SYNOPSIS
 
